#!/bin/bash
################################################################################
#
# COPYRIGHT:
#
# (C) Copyright International Business Machines Corporation 2012. 
# Licensed Material - Property of IBM - All Rights Reserved.
#
# U.S. Government User Restricted Rights - Use, duplication or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corp.
#
# MODIFICATION HISTORY
#
#   2012-10-16 HB Initial version
#
################################################################################
#
# DESCRIPTION
#
# Uninstall LTFS SM fixpack by restoring latest backup.
################################################################################

# get current user
SCRIPT_USER=$(id -u -n)

# make sure script is run as LTFS SM system user
if [ "$SCRIPT_USER" != "dmae" ]; then
    echo "The script needs to be run as LTFS SM system user 'dmae'."
    exit 1
fi

# make sure LTFS SM home is set
if [ -z "$ADMIRA_HOME" ]; then
    echo "Environment variable ADMIRA_HOME is not set. Please verify your environment."
    exit 2
fi

# find latest backup file
BAK_BASEDIR=${ADMIRA_HOME}/backup
BAK_ARCHIVE=$(ls -t ${BAK_BASEDIR}/v*.tar.gz | head -1)
BAK_ARCHIVE_FILE=${BAK_ARCHIVE##${BAK_BASEDIR}/}
# check whether we got the backup file
if [ -z "$BAK_ARCHIVE" -o  ! -f "${BAK_ARCHIVE}" ]; then
    echo "Failed to get backup archive."
    exit 3
fi


# retrieve current version
CURR_VERSION=$(dmae version | head -1 | cut -d' ' -f5-)
CURR_VERSION=${CURR_VERSION%.}

# check whether we got the version information
if [ -z "$CURR_VERSION" ]; then
    echo "Failed to retrieve LTFS SM version information."
    exit 3
fi


# get confirmation for restoring backup files
echo "================================================================================"
echo "This script will uninstall LTFS Storage Manager fixpack"
echo "'$CURR_VERSION' and restore files from"
echo "backup archive '${BAK_ARCHIVE_FILE}'."
echo "Make sure that LTFS Storage Manager is down before continuing."
echo "Do you want to start the uninstallation now [y|N]?"
    read answer
    case $answer in
        y*|Y*) ;;
        *) echo "Uninstallation cancelled by user."
           exit 4;;
    esac
echo "================================================================================"

echo
echo "Restoring files from ${BAK_ARCHIVE_FILE}..."
TARGET_DIR=${ADMIRA_HOME}
tar xvfz ${BAK_ARCHIVE} -C${TARGET_DIR} || \
{
    echo "Failed to restore backup from archive ${BAK_BASEDIR}/${BAK_ARCHIVE}."
    exit 5
}

CURR_VERSION=$(dmae version | head -1 | cut -d' ' -f5-)
echo 
echo "================================================================================"
echo "Uninstallation of LTFS Storage Manager fixpack succeeded."
echo "Restored LTFS Storage Manager version: $CURR_VERSION"
echo "================================================================================"
exit 0

	
